@@ -28,13 +28,12 @@ class MapScene;
 
 class MapView : public QGraphicsView
 {
-    Q_OBJECT
 public:
     explicit MapView( MapScene* scene, QWidget *parent = 0 );
     
 private:
-    virtual void resizeEvent( QResizeEvent* );
-    virtual QSize sizeHint() const;
+    void resizeEvent( QResizeEvent* ) override;
+    QSize sizeHint() const override;
 
     MapScene* m_scene;
 };
